@@ -1,5 +1,3 @@
-#include <sys/types.h>
-
 #include <ctype.h>
 #include <errno.h>
 #include <stdint.h>
@@ -103,7 +101,7 @@ static FeedTag * gettag(enum FeedType, const char *, size_t);
 static long gettzoffset(const char *);
 static int  isattr(const char *, size_t, const char *, size_t);
 static int  istag(const char *, size_t, const char *, size_t);
-static int  parsetime(const char *, time_t *);
+static int  parsetime(const char *, long long *);
 static void printfields(void);
 static void string_append(String *, const char *, size_t);
 static void string_buffer_realloc(String *, size_t);
@@ -215,7 +213,7 @@ static FeedContext ctx;
 static XMLParser parser; /* XML parser state */
 static String attrispermalink, attrrel, attrtype, tmpstr;
 
-int
+static int
 tagcmp(const void *v1, const void *v2)
 {
 	return strcasecmp(((FeedTag *)v1)->name, ((FeedTag *)v2)->name);
@@ -323,9 +321,9 @@ string_print_encoded(String *s)
 
 	for (; *p && p != e; p++) {
 		switch (*p) {
-		case '\n': fputs("\\n",  stdout); break;
-		case '\\': fputs("\\\\", stdout); break;
-		case '\t': fputs("\\t",  stdout); break;
+		case '\n': putchar('\\'); putchar('n'); break;
+		case '\\': putchar('\\'); putchar('\\'); break;
+		case '\t': putchar('\\'); putchar('t'); break;
 		default:
 			/* ignore control chars */
 			if (!iscntrl((unsigned char)*p))
@@ -362,7 +360,8 @@ string_print_trimmed(String *s)
 	printtrimmed(s->data);
 }
 
-void
+/* Print each field with trimmed whitespace, separated by '|'. */
+static void
 string_print_trimmed_multi(String *s)
 {
 	char *p, *e;
@@ -385,8 +384,8 @@ string_print_trimmed_multi(String *s)
 	}
 }
 
-/* print URL, if it's a relative URL then it uses global baseurl */
-void
+/* Print URL, if it's a relative URL then it uses the global `baseurl`. */
+static void
 printuri(char *s)
 {
 	char link[4096], *p, *e;
@@ -411,8 +410,8 @@ printuri(char *s)
 	*e = c; /* restore NUL byte to original character */
 }
 
-/* print URL, if it's a relative URL then it uses global baseurl */
-void
+/* Print URL, if it's a relative URL then it uses the global `baseurl`. */
+static void
 string_print_uri(String *s)
 {
 	if (!s->data || !s->len)
@@ -421,20 +420,21 @@ string_print_uri(String *s)
 	printuri(s->data);
 }
 
-/* print as UNIX timestamp, print nothing if the parsed time is invalid */
-void
+/* Print as UNIX timestamp, print nothing if the time is empty or invalid. */
+static void
 string_print_timestamp(String *s)
 {
-	time_t t;
+	long long t;
 
 	if (!s->data || !s->len)
 		return;
 
 	if (parsetime(s->data, &t) != -1)
-		printf("%lld", (long long)t);
+		printf("%lld", t);
 }
 
-long long
+/* Convert time fields. Returns a UNIX timestamp. */
+static long long
 datetounix(long long year, int mon, int day, int hour, int min, int sec)
 {
 	static const int secs_through_month[] = {
@@ -540,8 +540,10 @@ gettzoffset(const char *s)
 	return 0;
 }
 
+/* Parse time string `s` into the UNIX timestamp `tp`.
+   Returns 0 on success or -1 on failure. */
 static int
-parsetime(const char *s, time_t *tp)
+parsetime(const char *s, long long *tp)
 {
 	static struct {
 		char *name;
@@ -647,12 +649,12 @@ parsetime(const char *s, time_t *tp)
 	    va[2] < 1 || va[2] > 31 ||
 	    va[3] < 0 || va[3] > 23 ||
 	    va[4] < 0 || va[4] > 59 ||
-	    va[5] < 0 || va[5] > 59)
+	    va[5] < 0 || va[5] > 60) /* allow leap second */
 		return -1;
 
-	if (tp)
-		*tp = datetounix(va[0] - 1900, va[1] - 1, va[2], va[3], va[4], va[5]) -
-		      gettzoffset(s);
+	*tp = datetounix(va[0] - 1900, va[1] - 1, va[2], va[3], va[4], va[5]) -
+	      gettzoffset(s);
+
 	return 0;
 }
 
@@ -801,8 +803,6 @@ xmlattrstart(XMLParser *p, const char *t, size_t tl, const char *n, size_t nl)
 		string_clear(&tmpstr); /* use the last value for multiple attribute values */
 }
 
-/* NOTE: this handler can be called multiple times if the data in this
- *       block is bigger than the buffer. */
 static void
 xmldata(XMLParser *p, const char *s, size_t len)
 {
