@@ -229,8 +229,8 @@ die(const char *fmt, ...)
 
 	if (saved_errno)
 		fprintf(stderr, ": %s", strerror(saved_errno));
+	putc('\n', stderr);
 	fflush(stderr);
-	write(2, "\n", 1);
 
 	_exit(1);
 }
@@ -265,14 +265,15 @@ estrdup(const char *s)
 	return p;
 }
 
-/* Wrapper for tparm which allows NULL parameter for str. */
+/* Wrapper for tparm() which allows NULL parameter for str. */
 char *
-tparmnull(char *str, long p1, long p2, long p3, long p4, long p5, long p6,
+tparmnull(const char *str, long p1, long p2, long p3, long p4, long p5, long p6,
           long p7, long p8, long p9)
 {
 	if (!str)
 		return NULL;
-	return tparm(str, p1, p2, p3, p4, p5, p6, p7, p8, p9);
+	/* some tparm() implementations have char *, some have const char * */
+	return tparm((char *)str, p1, p2, p3, p4, p5, p6, p7, p8, p9);
 }
 
 /* Counts column width of character string. */
@@ -950,8 +951,10 @@ readch(void)
 	fd_set readfds;
 	struct timeval tv;
 
-	if (cmdenv && *cmdenv)
-		return *(cmdenv++);
+	if (cmdenv && *cmdenv) {
+		b = *(cmdenv++); /* $SFEED_AUTOCMD */
+		return (int)b;
+	}
 
 	for (;;) {
 		FD_ZERO(&readfds);
@@ -1204,6 +1207,7 @@ updatenewitems(struct feed *f)
 	size_t i;
 
 	p = &panes[PaneItems];
+	p->dirty = 1;
 	f->totalnew = 0;
 	for (i = 0; i < p->nrows; i++) {
 		row = &(p->rows[i]); /* do not use pane_row_get() */
@@ -1237,8 +1241,6 @@ feed_load(struct feed *f, FILE *fp)
 		p->rows[i].data = &(items.items[i]); /* do not use pane_row_get() */
 
 	updatenewitems(f);
-
-	p->dirty = 1;
 }
 
 void
@@ -2107,28 +2109,29 @@ main(int argc, char *argv[])
 				break;
 			case 'A': goto keyup;    /* arrow up */
 			case 'B': goto keydown;  /* arrow down */
-			case 'C': goto keyright; /* arrow left */
-			case 'D': goto keyleft;  /* arrow right */
+			case 'C': goto keyright; /* arrow right */
+			case 'D': goto keyleft;  /* arrow left */
 			case 'F': goto endpos;   /* end */
 			case 'H': goto startpos; /* home */
+			case '1': /* home */
 			case '4': /* end */
-				if ((ch = readch()) < 0)
-					goto event;
-				if (ch == '~')
-					goto endpos;
-				continue;
 			case '5': /* page up */
-				if ((ch = readch()) < 0)
-					goto event;
-				if (ch == '~')
-					goto prevpage;
-				continue;
 			case '6': /* page down */
+			case '7': /* home: urxvt */
+			case '8': /* end: urxvt */
+				i = ch;
 				if ((ch = readch()) < 0)
 					goto event;
-				if (ch == '~')
-					goto nextpage;
-				continue;
+				if (ch == '~') {
+					switch (i) {
+					case '1': goto startpos;
+					case '4': goto endpos;
+					case '5': goto prevpage;
+					case '6': goto nextpage;
+					case '7': goto startpos;
+					case '8': goto endpos;
+					}
+				}
 			}
 			break;
 keyup:
