@@ -13,7 +13,7 @@ static void
 printfeed(FILE *fp, const char *feedname)
 {
 	char *fields[FieldLast];
-	struct tm *tm;
+	struct tm parsedtm, *tm;
 	time_t parsedtime;
 	ssize_t linelen;
 
@@ -24,7 +24,7 @@ printfeed(FILE *fp, const char *feedname)
 
 		parsedtime = 0;
 		if (!strtotime(fields[FieldUnixTimestamp], &parsedtime) &&
-		    (tm = gmtime(&parsedtime))) {
+		    (tm = gmtime_r(&parsedtime, &parsedtm))) {
 			fprintf(stdout, "%04d-%02d-%02dT%02d:%02d:%02dZ\t",
 			        tm->tm_year + 1900, tm->tm_mon + 1, tm->tm_mday,
 			        tm->tm_hour, tm->tm_min, tm->tm_sec);
@@ -65,5 +65,6 @@ main(int argc, char *argv[])
 			fclose(fp);
 		}
 	}
+
 	return 0;
 }
